package jp.co.tao.sample.strictmode;

import java.io.IOException;

import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;

import android.app.Activity;
import android.content.ContentValues;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;

public class MainActivity extends Activity {
    private static final String TAG           = "test app";
    private static final String DATABASE_NAME = "test.db";
    private static final String TABLE_NAME    = "XXX";

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        StrictMode.enableDefaults();

        writeDatabase();
        readDatabase();

        readPreferences();
        writePreferences();
        writePreferencesApply();

        accessNetwork();
        slowMethod();
        permitDiskReadPolicy();
    }

    /***********************************
     * Databases
     ***********************************/
    private SQLiteDatabase mDb;

   
    private void readDatabase() {
        mDb = openOrCreateDatabase(DATABASE_NAME, MODE_PRIVATE, null);
        try {
            Cursor c = null;
            try {
                c = mDb.rawQuery("SELECT * FROM " + TABLE_NAME + ";", null);
            } finally {
                if (c != null)
                    c.close();
            }
        } catch (SQLiteException e) {
            Log.e(TAG, "SQLiteException: " + e);
        }

        mDb.close();
    }

    private void writeDatabase() {
        mDb = openDatabase();

        ContentValues values = new ContentValues();
        values.put("a", "1");

        mDb.insert(TABLE_NAME, null, values);
        mDb.close();
    }

    /**
     * Database Open & Create table
     * 
     * @return
     */
    private SQLiteDatabase openDatabase() {
        SQLiteDatabase db = null;
        try {
            db = openOrCreateDatabase(DATABASE_NAME, MODE_PRIVATE, null);
            createTable(db);
        } catch (SQLiteException e) {
            Log.e(TAG, "SQLiteException: " + e);
        }

        return db;
    }

    /**
     * テーブル作成
     * 
     * @param db
     */
    private void createTable(SQLiteDatabase db) {
        db.execSQL("CREATE TABLE IF NOT EXISTS " + TABLE_NAME + " (a INT);");
    }

    /***********************************
     * Preference
     ***********************************/

    private void writePreferences() {
        SharedPreferences prefs = getPreferences(MODE_PRIVATE);
        Editor editor = prefs.edit();
        editor.putString("key", "value");
        editor.commit();
    }

    private void writePreferencesApply() {
        SharedPreferences prefs = getPreferences(MODE_PRIVATE);
        Editor editor = prefs.edit();
        editor.putString("key", "valueApply");
        editor.apply();
    }

    private void readPreferences() {
        SharedPreferences prefs = getPreferences(MODE_PRIVATE);
        String value = prefs.getString("key", "");
        Log.v(TAG, value);
    }

    /***********************************
     * Network
     ***********************************/

    private void accessNetwork() {
        try {
            DefaultHttpClient httpClient = new DefaultHttpClient();
            HttpResponse res = httpClient.execute(new HttpGet("http://www.taosoftware.co.jp/"));
        } catch (IOException e) {
            Log.d(TAG, "HTTP fetch error: " + e);
        }
    }

    /***********************************
     * 独自
     ***********************************/

    private int slowMethod() {
        StrictMode.noteSlowCall("This method is very slow.");
        int ans = 0;
        for (int i = 0; i <= 100000; i++) {
            ans += i;
        }
        return ans;
    }

    /***********************************
     * ポリシチェンジ
     ***********************************/
    /**
     * allowThreadDiskReadsを使ったサンプル
     */
    void permitDiskReadPolicy() {

        // ディスクの読み込み処理を許可
        StrictMode.ThreadPolicy savedPolicy = StrictMode.allowThreadDiskReads();

        // ディスクへの書き込み処理
        readPreferences();

        // Policyを元に戻す
        StrictMode.setThreadPolicy(savedPolicy);
    }

}